<?php
require __DIR__ . '/../config.php';
requireLogin();

// 画像リサイズ関数（GD）
function resizeImageGD(string $srcPath, string $dstPath, int $maxSide = 2000): bool {
    [$w, $h, $type] = getimagesize($srcPath);
    if (!$w || !$h) return false;
    $ratio = $w > $h ? $maxSide / $w : $maxSide / $h;
    $nw = (int)($w * $ratio);
    $nh = (int)($h * $ratio);

    switch ($type) {
        case IMAGETYPE_JPEG:
            $srcImg = imagecreatefromjpeg($srcPath);
            break;
        case IMAGETYPE_PNG:
            $srcImg = imagecreatefrompng($srcPath);
            break;
        default:
            return false;
    }

    $dstImg = imagecreatetruecolor($nw, $nh);
    imagecopyresampled($dstImg, $srcImg, 0, 0, 0, 0, $nw, $nh, $w, $h);

    switch ($type) {
        case IMAGETYPE_JPEG:
            imagejpeg($dstImg, $dstPath);
            break;
        case IMAGETYPE_PNG:
            imagepng($dstImg, $dstPath);
            break;
    }

    imagedestroy($srcImg);
    imagedestroy($dstImg);

    return true;
}

// 画像リサイズ関数（Imagick）
function resizeImageImagick(string $srcPath, string $dstPath, int $maxSide = 2000): bool {
    try {
        $im = new Imagick($srcPath);
        // 最大辺を 2000px に合わせてリサイズ（縦横比を維持）
        $im->resizeImage($maxSide, $maxSide, Imagick::FILTER_LANCZOS, 1, true);
        $im->writeImage($dstPath);
        $im->destroy();
        return true;
    } catch (Exception $e) {
        return false;
    }
}

// カテゴリー一覧読み込み
$cats = $pdo->query("SELECT * FROM categories ORDER BY name")->fetchAll(PDO::FETCH_ASSOC);

$error = '';
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $title = trim($_POST['title'] ?? '');
    $body  = trim($_POST['body']  ?? '');
    $category_id = (int)($_POST['category'] ?? 0);

    if ($title === '' || $body === '' || $category_id <= 0) {
        $error = '必須項目が未入力です';
    }

    // 画像アップロード処理
    $imagePath = null;
    if (!$error && !empty($_FILES['image']['name'])) {
        $okTypes = ['image/jpeg', 'image/png', 'image/gif'];
        if (in_array($_FILES['image']['type'], $okTypes, true) && $_FILES['image']['error'] === UPLOAD_ERR_OK) {
            $upDir = __DIR__ . '/uploads/';
            if (!is_dir($upDir)) {
                mkdir($upDir, 0755, true);
            }
            $fn = time() . '_' . basename($_FILES['image']['name']);
            $fullPath = $upDir . $fn;
            if (move_uploaded_file($_FILES['image']['tmp_name'], $fullPath)) {
                // 画像サイズが大きい場合のみリサイズ（最大辺 2000px）
                [$w, $h] = getimagesize($fullPath);
                if ($w > 2000 || $h > 2000) {
                    if (extension_loaded('gd')) {
                        resizeImageGD($fullPath, $fullPath, 2000);
                    } elseif (extension_loaded('imagick')) {
                        resizeImageImagick($fullPath, $fullPath, 2000);
                    }
                }
                $imagePath = 'uploads/' . $fn;
            } else {
                $error = '画像アップロードに失敗しました';
            }
        } else {
            $error = '未対応の画像形式です';
        }
    }

    if (!$error) {
        $stmt = $pdo->prepare("
            INSERT INTO contents (title, body, image, category_id)
            VALUES (:title, :body, :img, :cat)
        ");
        $stmt->execute([
            ':title' => $title,
            ':body'  => $body,
            ':img'   => $imagePath,
            ':cat'   => $category_id,
        ]);
        header('Location: content_list.php');
        exit;
    }
}
?>
<!doctype html>
<html lang="ja">
<head>
  <meta charset="utf-8">
  <title>コンテンツ登録</title>
  <link rel="stylesheet" href="style.css">
</head>
<body>
  <div class="container">
    <h1>コンテンツ登録</h1>
    <?php if ($error): ?>
      <p class="error"><?= htmlspecialchars($error, ENT_QUOTES) ?></p>
    <?php endif; ?>
    <form action="" method="post" enctype="multipart/form-data">
      <div>
        <label>タイトル
          <input class="form-control" type="text" name="title" value="<?= htmlspecialchars($title ?? '', ENT_QUOTES) ?>">
        </label>
      </div>
      <div>
        <label>本文
          <textarea class="form-control" name="body" rows="5"><?= htmlspecialchars($body ?? '', ENT_QUOTES) ?></textarea>
        </label>
      </div>
      <div>
        <label>カテゴリー
          <select class="form-control" name="category">
            <option value="">選択してください</option>
            <?php foreach ($cats as $c): ?>
              <option value="<?= $c['id'] ?>" <?= (isset($category_id) && $category_id == $c['id']) ? 'selected' : '' ?>>
                <?= htmlspecialchars($c['name'], ENT_QUOTES) ?>
              </option>
            <?php endforeach; ?>
          </select>
        </label>
      </div>
      <div>
        <label>画像アップロード
          <input class="form-control" type="file" name="image" accept="image/*">
        </label>
      </div>
      <button class="btn btn-primary" type="submit">登録</button>
    </form>
    <p><a href="dashboard.php">← ダッシュボードに戻る</a></p>
  </div>
</body>
</html>
